==> qase_pytest-1.0.0a3-py2.py3-none-any.whl: qaseio/pytest/conftest.py <==
from qaseio.pytest.plugin import QasePytestPlugin


def get_option_ini(config, *names):
    for name in names:
        ret = config.getoption(name)  # 'default' arg won't work as expected
        if ret is None:
            ret = config.getini(name)
        if ret:
            return ret


def pytest_addoption(parser):
    group = parser.getgroup("qase")

    def add_option_ini(option, dest, default=None, type=None, **kwargs):
        parser.addini(
            dest,
            default=default,
            type=type,
            help="default value for " + option,
        )
        group.addoption(option, dest=dest, **kwargs)

    add_option_ini(
        "--qase",
        "qs_enabled",
        default=False,
        type="bool",
        help="Use Qase TMS",
        action="store_true",
    )
    add_option_ini(
        "--qase-api-token", "qs_api_token", help="Api token for Qase TMS",
    )
    add_option_ini(
        "--qase-project", "qs_project_code", help="Project code in Qase TMS",
    )
    add_option_ini(
        "--qase-testrun", "qs_testrun_id", help="Testrun ID in Qase TMS",
    )
    add_option_ini(
        "--qase-debug",
        "qs_debug",
        type="bool",
        help="Prints additional output of plugin",
    )


def pytest_configure(config):
    if get_option_ini(config, "qs_enabled"):
        config.pluginmanager.register(
            QasePytestPlugin(
                get_option_ini(config, "qs_api_token"),
                get_option_ini(config, "qs_project_code"),
                get_option_ini(config, "qs_testrun_id"),
                debug_info=get_option_ini(config, "qs_debug"),
            ),
            name="qase-pytest",
        )

==> qase_pytest-1.1.0b1-py2.py3-none-any.whl: qaseio/pytest/conftest.py <==
from qaseio.pytest.plugin import QasePytestPlugin


def get_option_ini(config, name):
    ret = config.getoption(name)  # 'default' arg won't work as expected
    if ret in (None, False):
        ret = config.getini(name)
    return ret


def pytest_addoption(parser):
    group = parser.getgroup("qase")

    def add_option_ini(option, dest, default=None, type=None, **kwargs):
        parser.addini(
            dest,
            default=default,
            type=type,
            help="default value for " + option,
        )
        group.addoption(option, dest=dest, **kwargs)

    add_option_ini(
        "--qase",
        "qs_enabled",
        default=False,
        type="bool",
        help="Use Qase TMS",
        action="store_true",
    )
    add_option_ini(
        "--qase-api-token", "qs_api_token", help="Api token for Qase TMS",
    )
    add_option_ini(
        "--qase-project", "qs_project_code", help="Project code in Qase TMS",
    )
    add_option_ini(
        "--qase-testrun", "qs_testrun_id", help="Testrun ID in Qase TMS",
    )
    add_option_ini(
        "--qase-new-run",
        "qs_new_run",
        default=False,
        type="bool",
        help="Create new testrun, if no testrun id provided",
        action="store_true",
    )
    add_option_ini(
        "--qase-debug",
        "qs_debug",
        default=False,
        type="bool",
        help="Prints additional output of plugin",
        action="store_true",
    )


def pytest_configure(config):
    config.addinivalue_line(
        "markers", "qase(*ids): mark test to be associate with Qase TMS"
    )
    if get_option_ini(config, "qs_enabled"):
        config.pluginmanager.register(
            QasePytestPlugin(
                api_token=get_option_ini(config, "qs_api_token"),
                project=get_option_ini(config, "qs_project_code"),
                testrun=get_option_ini(config, "qs_testrun_id"),
                create_run=get_option_ini(config, "qs_new_run"),
                debug=get_option_ini(config, "qs_debug"),
            ),
            name="qase-pytest",
        )
